H型钢的利用率是什么_公司新闻_H型钢_H型钢价格_热轧H型钢_焊接H型钢_高频焊接H型钢-天津郎丰达金属制品有限公司

﻿

# 缅甸银河国际网址

您好!歡迎進入天津郎豐達金屬制品有限公司網站 !

設為首頁|收藏本站
熱門關鍵詞: H型鋼 鍍鋅H型鋼 焊接H型鋼 高頻焊接H型鋼 其他型鋼
欄目導航

- 行業資訊
- 公司新聞

聯系我們

服務熱線

022-85103518
13612183033

聯系人：李經理

電話：022-85103518

手機：13612183033

當前位置：首頁 > 新聞中心 > 公司新聞
H型鋼的利用率是什么
瀏覽：167 發布日期：2019-04-25 11:42:00

H型鋼在進行操作時主要是指以熱軋或者是冷軋帶鋼為原料，在常溫的狀態下經壓力加工制成的各種復雜斷面型材，亦稱薄壁型鋼，是輕型建筑結構鋼材的一種。H型鋼是以熱軋或冷軋帶鋼為坯料經彎曲成型制成的各種截面形狀尺寸的型鋼。

H型鋼具有以下特點

缅甸银河国际网址　　1。 截面經濟合理,節省材料,其H型鋼的截面形狀是可以根據需要設計,結構合理,單位重量的截面系數高于熱軋型鋼。在同樣負荷下,可減輕構件重量,節約材料。H型鋼用于建筑結構可比熱軋型鋼節約金屬38%～50%,用于農業機械和車輛可節約金屬15%～60%。方便施工,降低綜合費用。

2. H型鋼的品種繁多，在進行操作時可以生產用一般熱軋方法難以生產的壁厚均勻、截面形狀復雜的各種型材和各種不同材質的H型鋼。

3。產品表面光潔,外觀好,尺寸精確,而且長度也可以根據需要靈活調整,全部按定尺或倍尺供應,提高材料的利用率。

缅甸银河国际网址　　4.生產中還可與沖孔等工序相配合，以滿足不同的需要。

H型鋼主要是采用其普通的碳素結構鋼以及優質的碳素結構鋼、低合金結構鋼板或鋼帶冷彎制成。H型鋼是屬于經濟斷面鋼材，也是高效節能材料，是一種具有強大生命力的新型鋼材品種，它廣泛應用于國家經濟的各個領域，其用途大約可以分為公路護欄板、鋼結構、汽車、集裝箱、鋼模板和腳手架、鐵道車輛、船舶和橋梁、鋼板樁、輸電鐵塔、其他10大類。

上一篇： H型鋼的特點分析

下一篇： H型鋼的結構及除銹問題